# This makefile compiles source files and then inserts them into 
# the libMC.so.$(version) shared library in current directory
# A symbolic link to 'libMC.so.$(version)' is created in $(libpath)
# A symbolic links to header files 'mccormick.h' is also created in
# $(includepath)

soname       = libMC.so
version      = 0.1.1
libtarget    = $(soname).$(version)

include $(srcpath)/makeoptions.mk

#####

libobjs = mccormick.o utils.o

includeobjs = mccormick.h
includedeps = 

#####

lib : dispBuild $(libobjs) 
	$(archive) $(archflags) -o $(libtarget) $(libobjs)
	@if test ! -e $(libpath)/$(libtarget); then \
		echo creating symolic link to shared library $(libtarget); \
		cd $(libpath); ln -s $(mcpath)/$(libtarget) $(libtarget); \
	fi
	@if test ! -e $(libpath)/$(soname); then \
		echo creating symolic link to shared library $(libtarget); \
		cd $(libpath); ln -s $(libtarget) $(soname); \
	fi
	@for INC in $(includeobjs); do \
		if test ! -e $(includepath)/$$INC; then \
			echo creating symolic link to header file $$INC; \
			cd $(includepath); ln -s $(mcpath)/$$INC $$INC; \
		fi; \
	done
	@echo

dispBuild:
	@echo
	@(echo '***Building McCormick library (ver.' $(version) ')***')
	@echo

mccormick.o : mccormick.cc $(includeobjs) $(includedeps)
	$(cpp) -c -I$(includepath) $(prof) $(cppflags) -o $@ $<

utils.o : utils.cc $(includeobjs) $(includedeps)
	$(cpp) -c -I$(includepath) $(prof) $(cppflags) -o $@ $<

#####

clean : dispClean
	rm -f *.o $(libtarget)
	cd $(libpath) ; rm -i $(libtarget) $(soname)
	cd $(includepath) ; rm -i $(includeobjs)

dispClean:
	@echo
	@(echo '***Cleaning McCormick library (ver.' $(version) ')***')
	@echo
